#
# spec file for package python-qrcode
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-qrcode
Version:        5.1
Release:        5.5
Summary:        QR Code image generator
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/lincolnloop/python-qrcode
Source:         http://pypi.python.org/packages/source/q/qrcode/qrcode-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This module uses the Python Imaging Library (PIL) to allow for the generation
of QR Codes.

%prep
%setup -q -n qrcode-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv -v %{buildroot}%{_bindir}/qr %{buildroot}%{_bindir}/qr-%{py_ver}
# rename man page too
mv -v %{buildroot}%{_mandir}/man1/qr.1 %{buildroot}%{_mandir}/man1/qr-%{py_ver}.1

ln -s -f %{_sysconfdir}/alternatives/qr %{buildroot}%{_bindir}/qr
ln -s -f %{_sysconfdir}/alternatives/qr.1%{?ext_man} %{buildroot}%{_mandir}/man1/qr.1%{?ext_man}

# create a dummy targets for /etc/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/qr
touch %{buildroot}%{_sysconfdir}/alternatives/qr.1%{?ext_man}

# Fix warning about missing +x mode 
chmod +x %{buildroot}%{python_sitelib}/qrcode/console_scripts.py

%pre
# Since /usr/bin/qr became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/qr ] || rm -f %{_bindir}/qr
[ -h %{_mandir}/man1/qr.1%{?ext_man} ] || rm -f %{_mandir}/man1/qr.1%{?ext_man}

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/qr qr %{_bindir}/qr-%{py_ver} 30 \
   --slave	 %{_mandir}/man1/qr.1%{?ext_man} qr.1%{?ext_man} %{_mandir}/man1/qr-%{py_ver}.1%{?ext_man}

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove qr %{_bindir}/qr-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc CHANGES.rst LICENSE README.rst
%{_bindir}/qr
%{_bindir}/qr-%{py_ver}
%{_mandir}/man1/qr.1%{?ext_man}
%{_mandir}/man1/qr-%{py_ver}.1%{?ext_man}
%ghost %{_sysconfdir}/alternatives/qr
%ghost %{_sysconfdir}/alternatives/qr.1%{?ext_man}
%{python_sitelib}/*

%changelog
* Sat Aug 22 2015 bruno@ioda-net.ch
- Make qr binary alternative ready (preparing for python3 packaging)
- man1 & qr alternative -py_ver to avoid conflict with python3
- Fix console_script.py missing +x
* Fri Jun  5 2015 hguo@suse.com
- Since factory project cannot make use of download_file service, the package
  no longer needs _service file to build.
* Mon Jun  1 2015 hguo@suse.com
- Upgrade to upstream release 5.1, accumulated changes:
  * Make qr script work in Windows. Thanks Ionel Cristian Mărieș
  * Fixed print_ascii function in Python 3.
  * Out-of-bounds code version numbers are handled more consistently with a ValueError.
  * Much better test coverage (now only officially supporting Python 2.6+)
  * Speed optimizations.
  * Change the output when using the qr script to use ASCII rather than just colors, better using the terminal real estate.
  * Fix a bug in passing bytecode data directly when in Python 3.
  * Substation speed optimizations to best-fit algorithm (thanks Jacob Welsh!).
  * Introduce a print_ascii method and use it as the default for the qr script rather than print_tty.
  * Update version numbers correctly.
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 4.0.4
  + Bad version number for previous hotfix release.
- Changes from version 4.0.3
  + Fix bad QR code generation due to the regex comma fix in version 4.0.2.
- Changes from version 4.0.2
  + Fix incorrect regex causing a comma to be considered part of the
    alphanumeric set.
- Add python-setuptools BuildRequires
* Wed Oct 23 2013 axel.braun@gmx.de
- update to 4.0.1
* Wed Aug  7 2013 prusnak@opensuse.org
- updated to 3.0
* Sat May 18 2013 prusnak@opensuse.org
- updated to 2.7
* Fri Mar 29 2013 prusnak@opensuse.org
- updated to 2.5.1
* Sun Mar 17 2013 prusnak@opensuse.org
- updated to 2.5
* Sat Dec 15 2012 prusnak@opensuse.org
- created package (version 2.4.2)
